@@ -27,13 +27,14 @@ class OMNIDashboard(TSDashboard):
         }
         ds_1 = self.dock(datasource_contents=['cdaweb', 'omni'], **omni_config)
         ds_2 = self.dock(datasource_contents=['wdc', 'ae'], allow_load=True, load_mode='AUTO')
-        ds_2 = self.dock(datasource_contents=['wdc', 'asysym'])
+        ds_3 = self.dock(datasource_contents=['wdc', 'asysym'])
+        ds_4 = self.dock(datasource_contents=['gfz', 'kpap'])
         # ds_1.list_all_variables()
         self.title = kwargs.pop('title', ', '.join([ds_1.facility, ds_1.omni_res]))
 
     def list_all_variables(self):
-        self.datasets[1].list_all_variables()
-        self.datasets[2].list_all_variables()
+        for key, dataset in self.datasets.items():
+            dataset.list_all_variables()
 
     def save_figure(self, **kwargs):
         file_name = kwargs.pop('filen_ame', self.title.replace(', ', '_'))
@@ -59,10 +60,12 @@ class OMNIDashboard(TSDashboard):
         sym_h = self.assign_variable('SYM_H', dataset=self.datasets[3])
         sym_h.visual.axis[1].lim = [None, None]
         sym_h.visual.axis[1].label = '@v.label'
+
+        kp = self.assign_variable('Kp', dataset=self.datasets[4])
         self.list_assigned_variables()
         self.list_datasets()
 
-        layout = [[Bx, [By], [Bz]], [v_sw], [n_p], [p_dyn], [au, al], [sym_h]]
+        layout = [[Bx, By, Bz], [v_sw], [n_p], [p_dyn], [au, al], [sym_h], [kp]]
         self.set_layout(panel_layouts=layout)
         # plt.style.use('dark_background')
         # dt_fr_1 = datetime.datetime.strptime('20201209' + '1300', '%Y%m%d%H%M')
@@ -75,21 +78,21 @@ class OMNIDashboard(TSDashboard):
 
 def example():
 
-    dt_fr = datetime.datetime.strptime('20180922' + '0600', '%Y%m%d%H%M')
-    dt_to = datetime.datetime.strptime('20180922' + '1800', '%Y%m%d%H%M')
+    dt_fr = datetime.datetime.strptime('20160314' + '0600', '%Y%m%d%H%M')
+    dt_to = datetime.datetime.strptime('20160320' + '0600', '%Y%m%d%H%M')
 
     omni_type = 'OMNI2'
     omni_res = '1min'
     load_mode = 'AUTO'
-    viewer = OMNIDashboard(
+    dashboard = OMNIDashboard(
         dt_fr, dt_to, omni_type=omni_type, omni_res=omni_res, load_mode=load_mode
     )
-    viewer.quicklook()
+    dashboard.quicklook()
 
     # save figure
-    # viewer.save_figure()
+    dashboard.save_figure()
     # show on screen
-    viewer.show()
+    dashboard.show()
 
 
 if __name__ == '__main__':
